@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:      4/12/2001
-// RCS-ID:      
-// Copyright:   (c) 2001-2002 Mattia Barbon
+// RCS-ID:      $Id: gr_constants.cpp,v 1.5 2003/05/05 20:38:42 mbarbon Exp $
+// Copyright:   (c) 2001-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -41,9 +41,7 @@ double grid_constant( const char* name, int arg )
         r( wxEVT_GRID_SELECT_CELL );
         r( wxEVT_GRID_EDITOR_SHOWN );
         r( wxEVT_GRID_EDITOR_HIDDEN );
-#if WXPERL_W_VERSION_GE( 2, 3, 1 )
         r( wxEVT_GRID_EDITOR_CREATED );
-#endif
         break;
     // !export: wxGridSelectCells wxGridSelectRows wxGridSelectColumns
     case 'G':
