@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     25/11/2000
-## RCS-ID:      $Id: App.pm,v 1.11 2003/05/04 17:31:56 mbarbon Exp $
+## RCS-ID:      $Id: App.pm,v 1.12 2003/08/17 19:34:40 mbarbon Exp $
 ## Copyright:   (c) 2000-2003 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -21,13 +21,13 @@ use strict;
 sub new {
   my $this;
 
+  my $class = ref( $_[0] ) || $_[0];
   if( ref( $Wx::wxTheApp ) ) {
-    my $class = ref( $_[0] ) || $_[0];
     bless $Wx::wxTheApp, $class;
     $this = $Wx::wxTheApp;
   } else {
-    #Wx::_croak( "Only one 'Wx::App' instance allowed" ) if $theapp;
     $this = $_[0]->SUPER::new();
+    bless $this, $class;
     $Wx::wxTheApp = $this;
   }
 
